@@ -13,10 +13,17 @@ extern "C" {
 #include <va/va.h>
 }
 
-class VaapiUtils
+#include "kpipewire_export.h"
+
+class KPIPEWIRE_EXPORT VaapiUtils
 {
+    // Utility struct to tag constructor as private while still allowing it to
+    // be used by make_shared().
+    struct Private {
+    };
+
 public:
-    VaapiUtils();
+    VaapiUtils(Private);
     ~VaapiUtils();
 
     bool supportsProfile(VAProfile profile);
@@ -26,7 +33,9 @@ public:
     QSize minimumSize() const;
     QSize maximumSize() const;
 
-    bool supportsHardwareModifiers() const;
+    bool supportsModifier(uint32_t format, uint64_t modifier);
+
+    static std::shared_ptr<VaapiUtils> instance();
 
 private:
     static VADisplay openDevice(int *fd, const QByteArray &path);
@@ -38,7 +47,6 @@ private:
 
     QByteArray m_devicePath;
 
-    mutable bool m_supportsHardwareModifiers = true;
     mutable QSize m_minSize;
     mutable QSize m_maxSize = QSize{std::numeric_limits<int>::max(), std::numeric_limits<int>::max()};
 };
